@@ -1,6 +1,6 @@
-init_leafdown <- function () {
-  states <- readRDS("testapps/us1-0005.RDS")
-  states2 <- readRDS("testapps/us2-0005.RDS")
+init_leafdown <- function() {
+  states <- readRDS("res/usa1.RDS")
+  states2 <- readRDS("res/usa2.RDS")
   spdfs_list <- list(states, states2)
   input <- shiny::reactiveValues(foo = "bar")
   my_leafdown <- Leafdown$new(spdfs_list, "leafdown", input)
